@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-hashed-storage-0.5.11/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: hashed-storage
-version: 0.5.10
-id: hashed-storage-0.5.10-5bca7b6ec5cb29a2b08c7f25931424a6
+version: 0.5.11
+id: hashed-storage-0.5.11-7e0d82807dfbc1f287ee832916f9898d
 
 license: BSD3
 copyright: 2009 Petr Rockai <me@mornfall.net>
@@ -28,29 +29,29 @@ exposed-modules: Storage.Hashed Storage.Hashed.AnchoredPath
                  Storage.Hashed.Darcs
 hidden-modules: Bundled.Posix Bundled.SHA256 Storage.Hashed.Utils
 trusted: False
-import-dirs: /usr/local/lib/ghc/hashed-storage-0.5.10
-library-dirs: /usr/local/lib/ghc/hashed-storage-0.5.10
-hs-libraries: HShashed-storage-0.5.10
+import-dirs: /usr/local/lib/ghc/hashed-storage-0.5.11
+library-dirs: /usr/local/lib/ghc/hashed-storage-0.5.11
+hs-libraries: HShashed-storage-0.5.11
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
-         binary-0.5.1.1-788edc729e11f89d940ee1b54cdabe88
-         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
-         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
-         dataenc-0.14.0.5-9969cfa6c78bd699cf9b75c7c37154a1
-         directory-1.2.0.1-8ba84e5bc37997efd0921897c80d9454
-         extensible-exceptions-0.1.1.4-255a395b3b026cb94b23754e1c372785
-         filepath-1.3.0.1-edbc3d8247914b04f448e9261e7fe895
-         mmap-0.5.8-eebbdde67c5a33fe7e439db44e0256ba
-         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
-         zlib-0.5.4.1-f8b2bb965704e7ec5caa162d83990faa
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         binary-0.7.1.0-c65c3b0b4e58d95c86bbb4173746e414
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         dataenc-0.14.0.7-cc208cdbbf6d6638baf121bf4724c834
+         directory-1.2.1.0-255ee2a4a618c74613f025ccc4ecc082
+         extensible-exceptions-0.1.1.4-ff00541964e8b4f6fe7adae94cd5f3b4
+         filepath-1.3.0.2-25a474a9272ae6260626ce0d70ad1cab
+         mmap-0.5.8-e3694e95a2a1f57eeae0561fc9764411
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         zlib-0.5.4.1-1316d824fe5105ceae8d375318b681e9
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hashed-storage-0.5.10/html/hashed-storage.haddock
-haddock-html: /usr/local/share/doc/hs-hashed-storage-0.5.10/html
+haddock-interfaces: /usr/local/share/doc/hs-hashed-storage-0.5.11/html/hashed-storage.haddock
+haddock-html: /usr/local/share/doc/hs-hashed-storage-0.5.11/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
